@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 
 my $log;
 my $bcmd;
@@ -237,7 +237,7 @@ sub instance_install {
                 next;
             }
         }
-        $bcmd->info_cache if $self->{args}{info_cache};
+        $bcmd->info_cache(1) if ! $self->{args}{nocache};
     }
     else {
         $log->_5("using existing versions only, nothing to install");
@@ -264,6 +264,7 @@ sub instance_remove {
         else {
             `$remove_cmd $version 2>/dev/null`;
         }
+        $bcmd->info_cache(1) if ! $self->{args}{nocache};
     }
     else {
         $log->_0("removing previous installs...");
@@ -285,10 +286,10 @@ sub instance_remove {
             else {
                 `$remove_cmd $installed_perl 2>/dev/null`;
             }
+            $bcmd->info_cache(1) if ! $self->{args}{nocache};
         }
     }
 
-    $bcmd->info_cache if $self->{args}{info_cache};
     $log->_4("removal of existing perl installs complete...");
 }
 sub revdep {
@@ -923,7 +924,8 @@ and for Unix, you'll need B<L<Perlbrew|http://perlbrew.pl>>.
 It allows you to remove and reinstall on each test run, install random versions
 of perl, or install specific versions.
 
-All unit tests are run against all installed instances.
+All unit tests are run against all installed instances, unless specified
+otherwise.
 
 =head1 SYNOPSIS
 
@@ -1101,15 +1103,6 @@ welcomed.
 
 L<https://github.com/stevieb9/p5-test-brewbuild/issues>
 
-=head1 SUPPORT
-
-You can find documentation for this module and its accompanying script with the
-perldoc command:
-
-    perldoc Test::BrewBuild
-
-    perldoc brewbuild
-
 =head1 SEE ALSO
 
 Berrybrew for Windows:
