@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 
 my $log;
 
@@ -75,7 +75,7 @@ sub using {
     $log->child( 'using' )->_6( "checking for which ver we're using" );
 
     if ($self->is_win) {
-        my @installed = $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]\*/ig;
+        my @installed = $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]\s+\*/ig;
         return $installed[0];
     }
     else {
@@ -127,11 +127,14 @@ sub is_win {
     return $is_win;
 }
 sub info_cache {
-    my ($self) = @_;
+    my ($self, $reset) = @_;
 
-    $log->child('info_cache')->_6("using cached availability info");
+    if ($reset){
+        $log->child('info_cache')->_7("resetting info_cache");
+        $self->{info_cache} = 0;
+    }
 
-    if (! defined $self->{info_cache}){
+    if (! $self->{info_cache}){
         $self->{info_cache} = $self->is_win
             ? `$self->{brew} available 2>nul`
             : `perlbrew available 2>/dev/null`;
@@ -139,6 +142,8 @@ sub info_cache {
         $log->child('info_cache')->_7("cached availability info");
     }
 
+    $log->child('info_cache')->_6("using cached availability info");
+
     return $self->{info_cache};
 }
 sub _legacy_perls {
@@ -189,7 +194,7 @@ C<berrybrew.exe> if on Windows.
 
 Returns the string result of C<*brew available>.
 
-=head2 info_cache
+=head2 info_cache($reset)
 
 Fetches, then caches the results of '*brew available'. This is due to the fact
 that perlbrew does an Internet lookup for the information, and berrybrew will
@@ -197,6 +202,13 @@ shortly as well.
 
 The cache is rebuilt on each new program run.
 
+Parameters:
+
+    $reset
+
+Bool, optional. Set to a true value to flush out the cache so it will be
+re-initialized.
+
 =head2 installed($info)
 
 Takes the output of C<*brew available> in a string form. Returns the currently
